@@ -10,6 +10,17 @@ def test_pypale_valid_token(_example_dot_com_1s_token: Pypale) -> None:
     assert _example_dot_com_1s_token.valid_token(return_token=token, return_email=email)
 
 
+def test_pypale_valid_token_with_extras(_example_dot_com_1s_token: Pypale) -> None:
+    email = test_email()
+    extras = {"foo": "bar"}
+    token = _example_dot_com_1s_token.generate_token(email=email, extras=extras)
+    assert _example_dot_com_1s_token.valid_token(return_token=token, return_email=email)
+    assert _example_dot_com_1s_token.decode_token(token=token)["foo"] == "bar"
+    assert (
+        _example_dot_com_1s_token.decode_token(token=token)["sub"] == "user@example.com"
+    )
+
+
 def test_pypale_invalid_token_wrong_user(_example_dot_com_1s_token: Pypale) -> None:
     email = test_email(name="userA")
     token = _example_dot_com_1s_token.generate_token(email=email)
